@@ -1,4 +1,7 @@
 from is_core.generic_views.detail_views import DjangoDetailFormView
+from is_core.generic_views.inlines.inline_form_views import TabularInlineFormView
+
+from issue_tracker.models import Issue
 
 
 class UserDetailView(DjangoDetailFormView):
@@ -6,3 +9,8 @@ class UserDetailView(DjangoDetailFormView):
     def leading_issue_name(self, obj):
         return obj.leading_issue.name if hasattr(obj, 'leading_issue') else 'No leading issue'
     leading_issue_name.short_description = 'leading issue name'
+
+
+class SubIssuesView(TabularInlineFormView):
+
+    model = Issue
